==> haskell-echo-0.1.3-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-echo.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: echo
version: 0.1.3
id: echo-0.1.3-K6IolejTib2L02PL91cWPC
key: echo-0.1.3-K6IolejTib2L02PL91cWPC
license: BSD3
copyright: (C) 2016-2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
stability: Provisional
homepage: https://github.com/RyanGlScott/echo
synopsis: A cross-platform, cross-console way to handle echoing terminal input
description:
    The @base@ library exposes the @hGetEcho@ and @hSetEcho@ functions
    for querying and setting echo status, but unfortunately, neither
    function works with MinTTY consoles on Windows. This is a serious
    issue, since @hGetEcho@ and @hSetEcho@ are often used to disable
    input echoing when a program prompts for a password, so many
    programs will reveal your password as you type it on MinTTY!
    .
    This library provides an alternative interface which works
    with both MinTTY and other consoles. An example is included
    which demonstrates how one might prompt for a password using
    this library. To build it, make sure to configure with the
    @-fexample@ flag.
category: System
author: Ryan Scott
exposed: True
exposed-modules:
    System.IO.Echo System.IO.Echo.Internal
abi: 0a8b579456d40fa98f9ef7826e502272
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/echo-0.1.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/echo-0.1.3
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/echo-0.1.3
hs-libraries: HSecho-0.1.3-K6IolejTib2L02PL91cWPC
depends:
    base-4.9.1.0 process-1.4.3.0
haddock-interfaces: /usr/share/doc/haskell-echo/html/echo.haddock
haddock-html: /usr/share/doc/haskell-echo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-echo-0.1.3-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-echo.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: echo
version: 0.1.3
id: echo-0.1.3-Bg2uuLn1Ivq5ZBFhk7SHx5
key: echo-0.1.3-Bg2uuLn1Ivq5ZBFhk7SHx5
license: BSD3
copyright: (C) 2016-2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
stability: Provisional
homepage: https://github.com/RyanGlScott/echo
synopsis: A cross-platform, cross-console way to handle echoing terminal input
description:
    The @base@ library exposes the @hGetEcho@ and @hSetEcho@ functions
    for querying and setting echo status, but unfortunately, neither
    function works with MinTTY consoles on Windows. This is a serious
    issue, since @hGetEcho@ and @hSetEcho@ are often used to disable
    input echoing when a program prompts for a password, so many
    programs will reveal your password as you type it on MinTTY!
    .
    This library provides an alternative interface which works
    with both MinTTY and other consoles. An example is included
    which demonstrates how one might prompt for a password using
    this library. To build it, make sure to configure with the
    @-fexample@ flag.
category: System
author: Ryan Scott
exposed: True
indefinite: False
exposed-modules:
    System.IO.Echo System.IO.Echo.Internal
abi: 1a7282017577f45f35509c95f0259302
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/echo-0.1.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/echo-0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/echo-0.1.3
hs-libraries: HSecho-0.1.3-Bg2uuLn1Ivq5ZBFhk7SHx5
depends:
    base-4.10.0.0 process-1.6.1.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             process-1.6.1.0=b3854816fc29ad3caa05e87ab6680404
haddock-interfaces: /usr/share/doc/haskell-echo/html/echo.haddock
haddock-html: /usr/share/doc/haskell-echo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
